english_word_dict = {
    "main_window_current_filename_format": "Current Filename: {name}",
    # File menu
    "main_window_open_image": "Open File",
    "main_window_current_filename": "Current Filename:",
    "main_window_current_file": "File",
    "main_window_open_folder": "Open Folder",
    "main_window_exit": "Exit",
    "main_window_tile_size": "Thumbnail Size",
    "main_window_select_folder": "Select Folder",
    "main_window_current_folder_format": "Current Folder: {path}",
    "main_window_remove_undo_stack": "Remove temp undo files",
    # Language Menubar
    "menu_bar_language": "Language",
    "language_menu_bar_please_restart_messagebox": "Please restart",
    "language_menu_bar_english": "English",
    "language_menu_bar_traditional_chinese": "Traditional Chinese",
    "language_menu_bar_chinese": "Chinese",
    "language_menu_bar_koren": "Korean",
    "language_menu_bar_japanese": "Japanese",
    # Tip menu
    "main_window_tip_menu": "Instructions",
    "main_window_mouse_tip_menu": "Mouse Control",
    "main_window_keyboard_tip_menu": "Keyboard Control",
    "mouse_control_middle_tip": "You can move using the mouse middle button",
    "mouse_control_left_tip": "Clicking an image with the left mouse button enters Deep zoom mode",
    "mouse_control_right_move_tip": "Hold down the right mouse button to multi-select images in thumbnail mode",
    "keyboard_control_esc_tip": "Press ESC to exit Deep zoom mode",
    "keyboard_control_tile_arrow_up_tip": "In thumbnail mode, use the Up arrow key to move upward",
    "keyboard_control_tile_arrow_down_tip": "In thumbnail mode, use the Down arrow key to move downward",
    "keyboard_control_tile_arrow_left_tip": "In thumbnail mode, use the Left arrow key to move left",
    "keyboard_control_tile_arrow_right_tip": "In thumbnail mode, use the Right arrow key to move right",
    "keyboard_control_delete_tip": "You can use Delete to remove images in both thumbnail and Deep zoom modes",
    "keyboard_r_tip": "Press the R key on the keyboard to reset the coordinates",
    # Right click menu
    "right_click_menu_go_to_parent_folder": "Go to Parent Folder",
    "right_click_menu_next_image": "Next Image",
    "right_click_menu_previous_image": "Previous Image",
    "right_click_menu_delete_current": "Delete Current Image",
    "right_click_menu_delete_selected": "Delete Selected Images",
    "right_click_menu_image_info": "Image Info",
    # Image info
    "image_info_filename": "Filename: {info}\n",
    "image_info_fullpath": "Full Path: {full_path}\n",
    "image_info_image_size": "Size: {width} x {height}\n",
    "image_info_file_size": "File Size: {file_size_mb} MB\n",
    "image_info_file_created_time": "Created Time: {created_time}\n",
    "image_info_file_modified_time": "Modified Time: {modified_time}\n",
    "image_info_messagebox_title": "Image Info",
    # Image info exif
    "image_info_exif_datatime_original": "Taken Time: {DateTimeOriginal}\n",
    "image_info_exif_camera_model": "Camera: {Make} {Model}\n",
    "image_info_exif_camera_lens_model": "Lens: {LensModel}\n",
    "image_info_exif_camera_focal_length": "Focal Length: {FocalLength}\n",
    "image_info_exif_camera_fnumber": "Aperture: {FNumber}\n",
    "image_info_exif_exposure_time": "Shutter: {ExposureTime}\n",
    "image_info_exif_iso": "ISO: {ISOSpeedRatings}",
    # Recent menu
    "recent_menu_title": "Recently Opened Menu",
}