traditional_chinese_word_dict = {
    "main_window_current_filename_format": "目前檔名： {name}",
    # File menu
    "main_window_open_image": "開啟檔案",
    "main_window_current_filename": "目前檔名：",
    "main_window_current_file": "檔案",
    "main_window_open_folder": "開啟資料夾",
    "main_window_exit": "離開",
    "main_window_tile_size": "縮圖大小",
    "main_window_select_folder": "選擇資料夾",
    "main_window_current_folder_format": "目前資料夾： {path}",
    "main_window_remove_undo_stack": "刪除暫存撤銷檔案",
    # Language Menubar
    "menu_bar_language": "語言",
    "language_menu_bar_please_restart_messagebox": "請重新啟動",
    "language_menu_bar_english": "英文",
    "language_menu_bar_traditional_chinese": "繁體中文",
    "language_menu_bar_chinese": "簡體中文",
    "language_menu_bar_koren": "韓文",
    "language_menu_bar_japanese": "日文",
    # Tip menu
    "main_window_tip_menu": "使用說明",
    "main_window_mouse_tip_menu": "滑鼠操作",
    "main_window_keyboard_tip_menu": "鍵盤操作",
    "mouse_control_middle_tip": "可以使用滑鼠中鍵移動",
    "mouse_control_left_tip": "滑鼠左鍵點擊圖片可以進入 Deep zoom 模式",
    "mouse_control_right_move_tip": "滑鼠右鍵按住可以在縮圖模式下複選圖片",
    "keyboard_control_esc_tip": "Deep zoom 模式下可以按 ESC 退出",
    "keyboard_control_tile_arrow_up_tip": "縮圖模式下可以使用方向鍵的上來往上移動",
    "keyboard_control_tile_arrow_down_tip": "縮圖模式下可以使用方向鍵的下來往下移動",
    "keyboard_control_tile_arrow_left_tip": "縮圖模式下可以使用方向鍵的左來往左移動",
    "keyboard_control_tile_arrow_right_tip": "縮圖模式下可以使用方向鍵的右來往右移動",
    "keyboard_control_delete_tip": "縮圖或 Deep zoom 模式都可以使用 Delete 來刪除圖片",
    "keyboard_r_tip": "可以按鍵盤上的 R 鍵，來重置座標",
    # Right click menu
    "right_click_menu_go_to_parent_folder": "前往父資料夾",
    "right_click_menu_next_image": "下一張圖",
    "right_click_menu_previous_image": "上一張圖",
    "right_click_menu_delete_current": "刪除目前的圖",
    "right_click_menu_delete_selected": "刪除選取的圖",
    "right_click_menu_image_info": "圖片資訊",
    # Image info
    "image_info_filename": "檔名: {info}\n",
    "image_info_fullpath": "完整路徑: {full_path}\n",
    "image_info_image_size": "尺寸: {width} x {height}\n",
    "image_info_file_size": "檔案大小: {file_size_mb} MB\n",
    "image_info_file_created_time": "建立時間: {created_time}\n",
    "image_info_file_modified_time": "修改時間: {modified_time}\n",
    "image_info_messagebox_title": "圖片資訊",
    # Image info exif
    "image_info_exif_datatime_original": "拍攝時間: {DateTimeOriginal}\n",
    "image_info_exif_camera_model": "相機: {Make} {Model}\n",
    "image_info_exif_camera_lens_model": "鏡頭: {LensModel}\n",
    "image_info_exif_camera_focal_length": "焦段: {FocalLength}\n",
    "image_info_exif_camera_fnumber": "光圈: {'FNumber'}\n",
    "image_info_exif_exposure_time": "快門: {ExposureTime}\n",
    "image_info_exif_iso": "ISO: {ISOSpeedRatings}",
    # Recent menu
    "recent_menu_title": "近期開啟選單",
}